
totStructs = 100          # number of structures to calculate
ensembleSize=2          # number of ensemble members
inFilename = "tor_cross_all_two_2_STRUCTURE_MEMBER.sa"
xrayFilename="gb3_xray.pdb"
nmrFilename = "tor_cross_all_one_1_mean.pdb"
fitFilename = "tor_cross_all_two_2_STRUCTURE_MEMBER.sa.fit"
ensembleFilename = "tor_cross_all_two_2_STRUCTURE.sa.ensemble"
meanFilename = "tor_cross_all_two_2_mean.pdb"
seed=54638326

sim = xplor.simulation
command = xplor.command


#
# load up needed packages
#

from atomAction import randomizeVelocities, translateFit, PrintPos
from rdcPotTools import create_RDCPot, scale_toNH, orderParameter
from varTensorTools import create_VarTensor, addAxisAtoms, calcTensor
from varTensorTools import configIVM, configIVM_fixDa, configIVM_fixRh
from varTensorTools import configIVM_varyDa, configIVM_varyRh
from atomSel import AtomSel
from ensembleSimulation import EnsembleSimulation
import ensembleSimulation
from xplorPot import XplorPot
from jCoupPot import JCoupPot
from noePot import NOEPot
from avePot import AvePot
from pdbTool import PDBTool
from shapePot import ShapePot
from math import sqrt, acos, pi
from vec3 import *
from simulationTools import *
from ncsPot import NCSPot
import simulation
import trace
import sys
import ivm
import selectTools
from selectTools import maxResid
from atomSelAction import *

simWorld.setRandomSeed(seed)
sys.stderr = sys.stdout #stderr is redirected to stdout




#----------------------------------------------------------------------
# read in the PSF file and initial structure


command("structure @gb3.psf end")

command("""
param
  @parallhdg_procheck_05.pro
end
""")

#for resid in (501, 502, 503, 504, 505):
#    addAxisAtoms(resid=resid)
#    pass

command("coor @%s" % xrayFilename)

command("coor copy end")

#
# create Simulation with ensembleSize ensemble members
#
esim = EnsembleSimulation("ensemble",ensembleSize)

targetCoords = esim.atomPosArr()


trace.suspend()

print "\nCalculating the mean coordinates\n"

zeroCoords = esim.atomPosArr()
for i in range(esim.numAtoms()):
    zeroCoords[i] = Vec3(0,0,0)
    pass

#meanCoords = CDSVector_Vec3(zeroCoords)
meanCoords = zeroCoords

structureCoords = []

def translateRotate(trans,rot,center,coords):
    ret = []
    for vec in coords:
        ret.append( trans + rot * (vec-center) )
        pass
    return ret
        

def structLoopAction(loopInfo):
    global inFilename, fitFilename
    global esim, meanCoords, zeroCoords, structureCoords
    PDBTool(loopInfo.makeFilename(inFilename),
            AtomSel("resid 1:56 or resname ANI")).read()

    ensembleMean = esim.meanAtomPosArr()
    
    structureCoords.append(ensembleMean)
                   
    fitter = Fit(targetCoords, AtomSel("name ca and resid 1:56"),ensembleMean)

    AtomSel("known").apply( fitter )
    
    #add in contribution to mean structure
    meanCoords += ensembleMean

    # apply rotation/translation to this ensemble member's coordinates
    AtomSel("known").apply( Rotate(fitter.rotation()) )
    AtomSel("known").apply( Translate(fitter.translation()) )

    # write out fitted structures
    PDBTool(loopInfo.makeFilename(fitFilename),
            AtomSel("resid 1:56 or resname ANI")).write()

    #write out ensemble-averaged structure
    esim.setAtomPosArr( ensembleMean )
    if esim.member().memberIndex()==0:
        PDBTool(loopInfo.makeFilename(ensembleFilename),
                AtomSel("resid 1:56 or resname ANI")).write()
    
    
    return
    

    

StructureLoop(numStructures=totStructs,
              structLoopAction=structLoopAction).run()

meanCoords.scale( 1.0/totStructs )

esim.setAtomPosArr( meanCoords ) # copy mean coordinates into simulation

if esim.member().memberIndex()==0:
    PDBTool(meanFilename,AtomSel("resid 1:56 or resname ANI")).write()
    pass

PDBTool(xrayFilename,AtomSel("resid 1:56")).read()
xrayCoords = esim.atomPosArr()

PDBTool(nmrFilename,AtomSel("resid 1:56")).read()
nmrCoords = esim.atomPosArr()

mean_rms = []
mean_rms_res= {}
xray_rms = []
xray_rms_res= {}
nmr_rms = []
nmr_rms_res= {}
for resid in range(1,maxResid("name CA")+1):
    mean_rms_res[resid] = 0.
    xray_rms_res[resid] = 0.
    nmr_rms_res[resid] = 0.
    pass

def fittedRMS(fitTo):
    #fit to alpha-Carbons
    AtomSel("known").apply( Fit(fitTo, AtomSel("name ca and resid 1:56")))
    measure = RMSD(fitTo)
    #measure rmsd of heavy bb atoms
    AtomSel("resid 1:56 and (name C or name CA or name N)").apply( measure )

    return ( measure.rmsd() , measure.byResidue() )

for coords in structureCoords:
    esim.setAtomPosArr(coords)

    mean_full, mean_byRes = fittedRMS(meanCoords)
    xray_full, xray_byRes = fittedRMS(xrayCoords)
    nmr_full, nmr_byRes = fittedRMS(nmrCoords)

    mean_rms.append( mean_full )
    xray_rms.append( xray_full )
    nmr_rms.append( nmr_full )

    for resid in mean_byRes.keys():
        mean_rms_res[resid] += mean_byRes[resid]
        xray_rms_res[resid] += xray_byRes[resid]
        nmr_rms_res[resid] += nmr_byRes[resid]
        pass
    
    pass

print "\nRMS of each (ensemble) structure from\n"
count=0
print "     %8s %8s %8s" % ("mean","xray","nmr")
for val in mean_rms:
    print "  %3d %8.2f %8.2f %8.2f" % (count, val,
                                       xray_rms[count], nmr_rms[count])
    count += 1
    pass


print "\nby-residue RMSD of ensemble mean structure to:\n"

print "resid %8s %8s %8s" % ("mean","xray","nmr")
for resid in range(1,56+1):
    print "%3d %8.3f %8.3f %8.3f"% (resid ,
                                    mean_rms_res[resid]/totStructs,
                                    xray_rms_res[resid]/totStructs,
                                    nmr_rms_res[resid]/totStructs)
    pass
