
totStructs = 100          # number of structures to calculate
ensembleSize=1           # number of ensemble members
filename = "tor_cross_all_one_%d_STRUCTURE_MEMBER.sa" % ensembleSize
globular_portion="known"
bondVectors=( ("N","HN"), ("CA","HA*"), ("N", "C"), ("CA", "C"))
seed=2

sim = xplor.simulation
command = xplor.command


#
# load up needed packages
#

from atomAction import randomizeVelocities, translateFit, PrintPos
from rdcPotTools import create_RDCPot, scale_toNH, orderParameter
from varTensorTools import create_VarTensor, addAxisAtoms, calcTensor
from varTensorTools import configIVM, configIVM_fixDa, configIVM_fixRh
from varTensorTools import configIVM_varyDa, configIVM_varyRh
from atomSel import AtomSel
from ensembleSimulation import EnsembleSimulation
import ensembleSimulation
from xplorPot import XplorPot
from jCoupPot import JCoupPot
from noePot import NOEPot
from avePot import AvePot
from pdbTool import PDBTool
from shapePot import ShapePot
from math import sqrt, acos, pi
from vec3 import *
from simulationTools import *
from ncsPot import NCSPot
from ensembleSimulation import EnsembleRMSD
import simulation
import trace
import sys
import ivm
import selectTools


simWorld.setRandomSeed(seed)
sys.stderr = sys.stdout #stderr is redirected to stdout
write = sys.stdout.write




#----------------------------------------------------------------------
# read in the PSF file and initial structure


command("structure @gb3.psf end")

command("""
param
  @parallhdg_procheck_05.pro
end
""")

command("coor @gb3_xray.pdb")


#command("delete select ((resid 73:76) or (resid 68 and name he2)) end")
#command("delete select (resid 68 and name he2) end")

#
# create Simulation with ensembleSize ensemble members
#
esim = EnsembleSimulation("ensemble",ensembleSize)

potList=PotList()





#
# now initialize dipolar coupling potential terms
#
ksani = 0.01

ksani_dic = {}
ksani_factor_dic = {}

ksani_factor_dic["jnhn"] = 1.000 
ksani_factor_dic["hnco"] = 5.0 
ksani_factor_dic["jnco"] = 25.0 
ksani_factor_dic["caco"] = 15.0 
ksani_factor_dic["caha"] = 0.44 

ksani_factor_dic["niconh"] = 1.0
ksani_factor_dic["nicohh1"] = 1.0
ksani_factor_dic["nicohh2"] = 1.0

ksani_factor_dic["j2co"] = ksani_factor_dic["jnco"] * \
                           (1.14 * 1.14)/(1.92 * 1.92 ) * 1.0
ksani_factor_dic["h2co"] = ksani_factor_dic["hnco"] * \
                           (2.99 * 2.99)/(5.22 * 5.22 ) * 1.0
ksani_factor_dic["c2co"] = ksani_factor_dic["caco"] * \
                           (1.87 * 1.87)/(3.14 * 3.14 ) * 1.0
ksani_factor_dic["c2ha"] = ksani_factor_dic["caha"] * \
                           (21.17*21.17)/(32.35*32.35 ) * 1.0
#ksani_j2hn_factor = ksani_jnhn_factor * (9.45 * 9.45)/(15.96 *15.96) * 1.0)
#ksani_factor_dic["j2hn"] = ksani_factor_dic["jnhn"]

for i in [1, 2, 4, 5, 6, 7, 8, 9, 10, 11]:
    ksani_factor_dic[i] = ksani_factor_dic["jnhn"] * 1.0
    ksani_dic[i] = ksani*ksani_factor_dic[i]
    pass

for key in ("jnhn", "hnco", "jnco", "caco", "h2co", "j2co", "c2co",
            "caha", "c2ha", "niconh", "nicohh1", "nicohh2"):
    ksani_dic[key] = ksani * ksani_factor_dic[key]
    pass

#ugly cleanup
del ksani_dic["jnhn"]



rdcs = {}


trace.suspend()

def create_and_setup_rdc(name,file):
    axis = addAxisAtoms()
    print "axis:", axis
    write("creating rdc[%8s]..." %name)
    oTensor=create_VarTensor(name,axis=axis)
    rdc = create_RDCPot(name,oTensor=oTensor,file=file)
    calcTensor(oTensor)
    #if esim.member().memberIndex()==0:
    #    AtomSel("resname ANI and name X",esim.members(0))[0].setPos(3,2,1)
    #    pass
    #AtomSel("resname ANI and name PA1",esim).apply(PrintPos())
    print " Da = %6.2f   Rh = %6.3f" % (oTensor.Da(), oTensor.Rh())
    oTensor.setEnsembleDa(1)
    oTensor.setEnsembleRh(1)
    # Da(0): want potential parameters to be *exactly* the same
    # for all simulation members
    global esim
    esim.sync()
    oTensor.setSpreadDa(1e-5*abs(oTensor.Da(0))) 
    oTensor.setSpreadRh(1e-5)
    oTensor.setScaleDa(1e5)
    oTensor.setScaleRh(1e5)
    return rdc

def create_dependent_rdc(name,file,type,rdc_nh):
    """create an rdc pot term for a non-NH expt. carried out in the
    same medium as the given nh expt.
    """
    write("creating rdc[%8s]..." %name)
    oTensor = rdc_nh.oTensor
    rdc = create_RDCPot(name,file,oTensor=oTensor)
    scale_toNH(rdc,type)
    print " Da = %6.2f   Rh = %6.3f" % (oTensor.Da(), oTensor.Rh())
    rdc.setAveType("sum")
    oTensor.setEnsembleDa(1)
    oTensor.setEnsembleRh(1)
    oTensor.setSpreadDa(1e-5*abs(rdc_nh.oTensor.Da(0)))
    oTensor.setSpreadRh(1e-5)
    oTensor.setScaleDa(1e5)
    oTensor.setScaleRh(1e5)
    return rdc
    

#
# HN-N rdc terms
#
rdcs = {}
rdc_scale = {}
#
# rdc terms are scaled relative to rdc_scaleRef: the scale factor
# is the square of the ratio of Das
#
rdc_scaleRef="nh_peg" 
for (name,file,scale) in (("nh_peg" ,"peg_nh.tbl"    ,15.0),
                          ("nh_bic" ,"bicelle_nh.tbl",15.0),
                          ("nh_ngel","ngel_nh.tbl"   ,15.0),
                          ("nh_pgel","pgel_nh.tbl"   ,15.0),
                          ("nh_pf1" ,"pf1_nh.tbl"    ,15.0)):
    rdcs[name] = create_and_setup_rdc(name,file)
    scale *= ( rdcs[rdc_scaleRef].oTensor.Da(0) /
               rdcs[name].oTensor.Da(0) )**2
    rdcs[name].setScale(scale)
    rdc_scale[name] = scale
    pass

    
for (name,nh_name,type,file,scale) in \
    (("caco_bic" ,"nh_bic" ,"CACO","bicelle_caco.tbl",100.0),
     ("caco_ngel","nh_ngel","CACO","ngel_caco.tbl"   ,100.0),         
     ("caco_pgel","nh_pgel","CACO","pgel_caco.tbl"   ,100.0),
     ("caco_pf1" ,"nh_pf1" ,"CACO","pf1_caco.tbl"    ,100.0),
     ("caco_peg" ,"nh_peg" ,"CACO","peg_caco.tbl"    ,100.0),
     ("ch_bic"   ,"nh_bic" ,"CAHA","bicelle_ch.tbl"  ,3.0),
     ("ch_ngel"  ,"nh_ngel","CAHA","ngel_ch.tbl"     ,3.0),
     ("ch_pgel"  ,"nh_pgel","CAHA","pgel_ch.tbl"     ,3.0),
     ("ch_pf1"   ,"nh_pf1" ,"CAHA","pf1_ch.tbl"      ,3.0),
     ("ch_peg"   ,"nh_peg" ,"CAHA","peg_ch.tbl"      ,3.0),
     ("nco_bic"  ,"nh_bic" ,"NCO" ,"bicelle_nco.tbl" ,100.0),
     ("nco_ngel" ,"nh_ngel","NCO" ,"ngel_nco.tbl"    ,100.0),
     ("nco_pgel" ,"nh_pgel","NCO" ,"pgel_nco.tbl"    ,100.0),
     ("nco_pf1"  ,"nh_pf1" ,"NCO" ,"pf1_nco.tbl"     ,100.0),
     ("nco_peg"  ,"nh_peg" ,"NCO" ,"peg_nco.tbl"     ,100.0)    ):
    rdcs[name] = create_dependent_rdc(name,file,type,rdcs[nh_name])
    scale *= ( rdcs[rdc_scaleRef].oTensor.Da(0) /
               rdcs[name].oTensor.Da(0) )**2
    rdcs[name].setScale(scale)
    rdc_scale[name] = scale
    pass



refineRDC = PotList("refineRDC")
crossRDC  = PotList("crossRDC")
media = ("bic", "ngel", "pgel", "pf1", "peg")
for expt in ["ch", "nh", "nco", "caco"]:
    for medium in media:
        refineRDC.add( rdcs[expt + '_' + medium] )
        refineRDC.add( rdcs[expt + '_' + medium].oTensor )
    pass
for expt in []:
    for medium in media: crossRDC.add( rdcs[expt + '_' + medium] )
    pass


command("""
hbda
  nres 800
  class back
  @hbda.tbl
  force 500.0
end
""")

#
# main structure loop
#

print "\nPerforming analysis\n"

def structLoopAction(loopInfo):
    global filename, esim, aveFittingAngle
    file = loopInfo.makeFilename( filename )
    PDBTool(file).read()

    #N-HN R factor calculation
    global rFactor, rCount
    for rdc in rdcs.values():
        rdc.calcEnergy()
        name = rdc.instanceName()
        print "analysis of", name
        print "resid R factor deviation"
        for restraint in rdc.restraints():
            resid = restraint.aSelection()[0].residueNum()
            aveDiff =0.
            t = rdc.oTensor
            Da = t.aveDa()*rdc.gyroA()
            dev = restraint.deviation() / \
                  abs( 3*Da + 1.5*Da* t.aveRh())
            rms = sqrt( aveDiff / esim.size() )
            rCount[name][resid] += 1
            aveDeviation[name][resid] += dev
            R = abs(restraint.diff()) / \
                sqrt(2*Da**2 *
                     (4 + 3 * t.aveRh()**2)/5)
            rFactor[name][resid] += R
            print "%3d %7.2f %7.2f" % (resid,R*100, dev*100)
            pass
        DaDiff =0.
        RhDiff =0.
        for i in range(esim.size()):
            for j in range(i+1,esim.size()):
                DaDiff += (t.Da(i) - t.Da(j))**2
                RhDiff += (t.Rh(i) - t.Rh(j))**2
                pass
            pass
        if DaDiff:
            DaDiff = rdc.gyroA() * sqrt(DaDiff* 2 /
                                        (esim.size()*(esim.size()-1)))
            pass
        aveDa[name] += t.aveDa()*rdc.gyroA()
        aveDaDiff[name] += DaDiff
        if RhDiff:
            RhDiff = sqrt(RhDiff* 2 /
                          (esim.size()*(esim.size()-1)))
            pass
        aveRhDiff[name] += RhDiff
        print "DaDiff: ", DaDiff/t.aveDa()*rdc.gyroA(), "  RhDiff: ", RhDiff
        pass
    
    # pairwise rmsd within an ensemble
    measure = EnsembleRMSD()
    AtomSel("(name N or name C or name CA)").apply(measure)
    print "average intra-ensemble rmsd:", measure.rmsd()
    for resid in measure.byResidue().keys():
        aveRMSD[resid] += measure.byResidue()[resid]
        pass
        
    # angle calculation
    print "per-residue bond angle deviation"
    for bondAtoms in bondVectors:
        aSelString = r'resid %d and name ' + bondAtoms[0]
        bSelString = r'bondedto id %d and name  ' + bondAtoms[1]
        for resid in range(1,selectTools.maxResid("name %s"%
                                                  bondAtoms[0])+1):
            try:
                bondVecs=[]
                for index in range( esim.size() ):
                    memberSim = esim.members(index)
                    aAtom = AtomSel(aSelString %resid,memberSim)[0]
                    bAtom = AtomSel(bSelString %(aAtom.index()+1),memberSim)[0]
                    bondVecs.append( aAtom.pos()-bAtom.pos() )
                    pass
                aveAngle=0.
                aveAngle_squ=0.
                count=0
                for i in range( esim.size() ):
                    for j in range( i+1, esim.size() ):
                        dp = dot(unitVec(bondVecs[i]),
                                 unitVec(bondVecs[j]))
                        if dp> 1.: dp = 1
                        if dp<-1.: dp = -1
                        angle = acos(dp  )
                        aveAngle += angle
                        count += 1
                        pass
                    pass
                if count: aveAngle /= count
                aveAngle*=180/pi
                aveAngle_squ=aveAngle*aveAngle
                aveAngles[bondAtoms][resid] += aveAngle
                aveAngles_squ[bondAtoms][resid] +=aveAngle**2 
                print bondAtoms, resid, aveAngle
            except IndexError:
                pass
            pass
        for atom in AtomSel("name %s" % bondAtoms[0]):
            try:
                resid = atom.residueNum()
                S2 = orderParameter(AtomSel(aSelString % resid),
                                    AtomSel(bSelString % (atom.index()+1)))
                aveS2[bondAtoms][resid] += S2
                aveS2_squ[bondAtoms][resid] += S2**2
            except IndexError:
                pass
            pass
        pass
    

    # now best-fit intra-ensemble structures
    savedCoords = esim.atomPosArr()
    esim.setAtomPosArr( esim.members(0).atomPosArr() )
    command("coor copy end")
    esim.setAtomPosArr( savedCoords )
    (kappa,) = map(float,
                   command("coor select (name ca) fit end",
                           ("AXIS_KAPPA")))
    # a cheap method of passing data between threads....
    esim.setAtomVel( 0, (kappa,0,0))
    esim.setAtomPosArr( esim.subSim().atomPosArr() )
    
    esim.barrier()

    aveAngle=0.
    for index in range(esim.size()):
        aveAngle += esim.members(index).atomVel(0)[0]
        pass
    if esim.size(): aveAngle /= esim.size()

    aveFittingAngle += aveAngle

    # repeat rms, angle calculations
    
    # pairwise rmsd within an ensemble
    measure = EnsembleRMSD()
    AtomSel("name N or name C or name CA").apply(measure)
    print "average intra-ensemble rmsd:", measure.rmsd()
    for resid in measure.byResidue().keys():
        fitted_aveRMSD[resid] += measure.byResidue()[resid]
        pass
        
                
            
    # angle calculation
    print "per-residue bond angle deviation"
    for bondAtoms in bondVectors:
        aSelString = r'resid %d and name ' + bondAtoms[0]
        bSelString = r'bondedto id %d and name ' + bondAtoms[1]
        for resid in range(1,selectTools.maxResid("name %s and name %s"%
                                                  bondAtoms)+1):
            try:
                bondVecs=[]
                for index in range( esim.size() ):
                    memberSim = esim.members(index)
                    aAtom = AtomSel(aSelString %resid,memberSim)[0]
                    bAtom = AtomSel(bSelString %(aAtom.index()+1),memberSim)[0]
                    bondVecs.append( aAtom.pos()-bAtom.pos() )
                    pass
                aveAngle=0.
                aveAngle_squ=0.
                count=0
                for i in range( esim.size() ):
                    for j in range( i+1, esim.size() ):
                        dp = dot(unitVec(bondVecs[i]),
                                 unitVec(bondVecs[j]))
                        if dp> 1.: dp = 1
                        if dp<-1.: dp = -1
                        angle = acos(dp  )
                        aveAngle += angle
                        count += 1
                        pass
                    pass
                if count: aveAngle /= count
                aveAngle*=180/pi
                aveAngle_squ=aveAngle*aveAngle
                fitted_aveAngles[bondAtoms][resid] += aveAngle
                fitted_aveAngles_squ[bondAtoms][resid] +=aveAngle**2 
                print bondAtoms, resid, aveAngle
            except IndexError:
                pass
            pass
        for atom in AtomSel("name %s" % bondAtoms[0]):
            try:
                resid = atom.residueNum()
                S2 = orderParameter(AtomSel(aSelString % resid),
                                    AtomSel(bSelString % (atom.index()+1)))
                fitted_aveS2[bondAtoms][resid] += S2
                fitted_aveS2_squ[bondAtoms][resid] += S2**2
            except IndexError:
                pass
            pass
        pass

    return


aveRMSD = {};   fitted_aveRMSD = {}; 
for resid in range(1,selectTools.maxResid()+1):
    aveRMSD[resid] = 0.
    fitted_aveRMSD[resid] = 0.
    pass

aveS2     = {}; fitted_aveS2 = {}
aveAngles = {}; fitted_aveAngles = {};
aveAngles_squ = { }; fitted_aveAngles_squ = {};
aveS2_squ = {}; fitted_aveS2_squ = {}
for bondAtoms in bondVectors:
    aveS2[bondAtoms]     = {}; fitted_aveS2[bondAtoms] = {}
    aveAngles[bondAtoms] = {}; fitted_aveAngles[bondAtoms] = {};
    aveAngles_squ[bondAtoms] = { }; fitted_aveAngles_squ[bondAtoms] = {};
    aveS2_squ[bondAtoms] = {}; fitted_aveS2_squ[bondAtoms] = {}
    
    for resid in range(1,selectTools.maxResid()+1):
        aveAngles[bondAtoms][resid] = 0.
        aveAngles_squ[bondAtoms][resid] = 0.
        fitted_aveAngles[bondAtoms][resid] = 0.
        fitted_aveAngles_squ[bondAtoms][resid] = 0.
        aveS2[bondAtoms][resid] = 0.
        aveS2_squ[bondAtoms][resid] = 0.
        fitted_aveS2[bondAtoms][resid] = 0.
        fitted_aveS2_squ[bondAtoms][resid] = 0.
        pass
    pass

rFactor = {}; rCount = {}; aveDeviation = {}
aveDa = {}; aveDaDiff = {}; aveRhDiff = {}
for rdc in rdcs.values():
    name = rdc.instanceName()
    rFactor[name] = {}; rCount[name] = {}; aveDeviation[name] = {}
    for resid in range(1,selectTools.maxResid("name N")+1):
        aveDeviation[name][resid] = 0.
        rFactor[name][resid] = 0.
        rCount[name][resid] = 0
        aveDa[name] = 0.
        aveDaDiff[name] = 0.
        aveRhDiff[name] = 0.
        pass
    pass
aveFittingAngle = 0.


StructureLoop(numStructures=totStructs,
              structLoopAction=structLoopAction).run()
    

print "                   structure-averaged data"
print
print " per experiment R-factors\n   "
keys = rdcs.keys(); keys.sort()
sys.stdout.write(" "*3);
for key in keys:
    rdc = rdcs[key]
    sys.stdout.write(" %7s"%rdc.instanceName())
    pass
print
print "-"*80
for resid in range(1,selectTools.maxResid("name N")+1):
    sys.stdout.write("%3d" % resid)
    for key in keys:
        rdc = rdcs[key]
        name = rdc.instanceName()
        R = rFactor[name][resid]*100
        if  rCount[name][resid]:
            R /= rCount[name][resid]
        sys.stdout.write(" %7.2f"%R)
        pass
    print
    pass
print
print " per experiment deviations\n   "
sys.stdout.write(" "*3);
for key in keys:
    rdc = rdcs[key]
    sys.stdout.write(" %7s"%rdc.instanceName())
    pass
print
print "-"*80
for resid in range(1,selectTools.maxResid("name N")+1):
    sys.stdout.write("%3d" % resid)
    for key in keys:
        rdc = rdcs[key]
        name = rdc.instanceName()
        dev = aveDeviation[name][resid]*100
        if  rCount[name][resid]:
            dev /= rCount[name][resid]
        sys.stdout.write(" %7.2f"%dev)
        pass
    print
    pass
print "\n ensemble Da percentage difference averaged over all structures\n   "
sys.stdout.write("   ");
for key in keys:
    name = rdcs[key].instanceName()
    sys.stdout.write(" %7.2f"%(100*aveDaDiff[name]/abs(aveDa[name])))
    pass
print "\n ensemble Rhombicity difference averaged over all structures\n   "
sys.stdout.write("   ");
for key in keys:
    name = rdcs[key].instanceName()
    sys.stdout.write(" %7.2f"%(aveRhDiff[name]/totStructs))
    pass
    
print "\n\nper-experiment R-factor and deviations averaged over media\n"
expts=[]
for rdc in rdcs.values():
    expt=rdc.instanceName().split("_")[0]
    if not expt in expts: expts.append(expt)
    pass

expts.sort()

header1="   resid"
header2="        "
for expt in expts:
    header1 += "  %12s     " % expt
    header2 += "  %8s %8s" % ('R-factor', 'deviat')
    pass

print header1
print header2
print "_"*len(header2)

for resid in range(1,selectTools.maxResid("name N")+1):
    resname = AtomSel("resid %d"%resid)[0].residueName()
    line =  "%3s %4d" % (resname, resid)

    for expt in expts:
        R = 0.
        dev = 0.
        count =0
        for rdc in filter(lambda x: x.instanceName().split("_")[0]==expt,
                          rdcs.values()                                  ):
            name = rdc.instanceName()
            R +=  rFactor[name][resid]
            dev +=  aveDeviation[name][resid]
            count += rCount[name][resid]
            pass
        if count:
            R *= 100./count
            dev  *= 100./count
            pass

        line += "  %8.2f %8.2f" % (R,dev)
        pass
    print line
    pass


print "\nAggregated quantities\n"
header1="   resid"
header2="        "
for keys in (('fitted','R-factor'),
             ('cross','R-factor'),
             ('deviat',''),
             ('rmsd',''),
             ('rmsd','fitted')):
    header1 += " %8s" % keys[0]
    header2 += " %8s" % keys[1]
    pass

print header1
print header2
print "_"*len(header2)

for resid in range(1,selectTools.maxResid("name N")+1):
    resname = AtomSel("resid %d and name N"%resid)[0].residueName()


    Rfit = 0.
    dev = 0.
    count =0
    for rdc in refineRDC:
        name = rdc.instanceName()
        Rfit +=  rFactor[name][resid]
        dev +=  aveDeviation[name][resid]
        count += rCount[name][resid]
        pass
    if count:
        Rfit *= 100./count
        dev  *= 100./count
        pass

    Rcross = 0.
    count =0
    for rdc in crossRDC:
        name = rdc.instanceName()
        Rcross  += rFactor[name][resid]
        count += rCount[name][resid]
        pass
    if count: Rcross *= 100./count
    
        
    rmsd        = aveRMSD[resid] / totStructs
    fitted_rmsd = fitted_aveRMSD[resid] / totStructs

    line =  "%3s %4d" % (resname, resid)
    for val in (Rfit, Rcross , dev, rmsd, fitted_rmsd):
        line += " %8.2f" % val
        pass
    print line
          
    pass

header1="   resid"
header2="        "
for keys in (('ang diff',''),
             ('ang sd',''),
             ('ang diff','fitted'),
             ('ang sd','fitted'),
             ('S2',''),
             ('S2 sd',''),
             ('S2','fitted'),
             ('S2 sd','fitted')):
    header1 += " %8s" % keys[0]
    header2 += " %8s" % keys[1]
    pass

for bondAtoms in bondVectors:
    print "\nanalysis of %s - %s bond vectors\n" % bondAtoms
    print header1
    print header2
    print "_"*len(header2)
    
    for resid in range(1,selectTools.maxResid("name N")+1):
        resname = AtomSel("resid %d and name N"%resid)[0].residueName()

        angle        =        aveAngles[bondAtoms][resid]/totStructs
        angle_sd     =        sqrt(aveAngles_squ[bondAtoms][resid]/totStructs -
                                   angle*angle)
        fitted_angle =        fitted_aveAngles[bondAtoms][resid]/totStructs
        fitted_angle_sd   =   sqrt(fitted_aveAngles_squ[bondAtoms][resid]/
                                   totStructs -
                                   fitted_angle*fitted_angle)
        S2        =           aveS2[bondAtoms][resid]/totStructs
        S2_sd     =           sqrt(aveS2_squ[bondAtoms][resid]/totStructs -
                                   S2*S2)
        fitted_S2 =           fitted_aveS2[bondAtoms][resid]/totStructs
        fitted_S2_sd     =    sqrt(fitted_aveS2_squ[bondAtoms][resid]/
                                   totStructs -
                                   fitted_S2*fitted_S2)


        rmsd        = aveRMSD[resid] / totStructs
        fitted_rmsd = fitted_aveRMSD[resid] / totStructs

        line =  "%3s %4d" % (resname, resid)
        for val in (angle, angle_sd, fitted_angle, fitted_angle_sd,
                    S2, S2_sd, fitted_S2, fitted_S2_sd):
            line += " %8.2f" % val
            pass
        print line
          
        pass
    pass

print "\naverage angle for intra-ensemble rmsd fit:", \
      aveFittingAngle/totStructs

