
totStructs = 100          # number of structures to calculate
ensembleSize=2           # number of ensemble members
                         # the next line should refer to fitted structures
                         # produced by analyze_mean.py
filename = "tor_cross_all_two_%d_STRUCTURE_MEMBER.sa.fit" % ensembleSize
bondVectors=( ("N","HN"), ("CA","HA*"), ("N", "C"), ("CA", "C"))
seed=3
compResids=range(1,57)


sim = xplor.simulation
command = xplor.command


#
# load up needed packages
#

from atomAction import randomizeVelocities, translateFit
from rdcPotTools import *
from atomSel import AtomSel
from ensembleSimulation import EnsembleSimulation
import ensembleSimulation
from xplorPot import XplorPot
from jCoupPot import JCoupPot
from noePot import NOEPot
from avePot import AvePot
from pdbTool import PDBTool
from shapePot import ShapePot
from math import sqrt, acos, pi
from vec3 import *
from simulationTools import *
from ncsPot import NCSPot
from ensembleSimulation import EnsembleRMSD
import simulation
import trace
import sys
import ivm
import selectTools


simWorld.setRandomSeed(seed)
sys.stderr = sys.stdout #stderr is redirected to stdout




#----------------------------------------------------------------------
# read in the PSF file and initial structure

command("structure @gb3.psf end")

command("""
param
  @parallhdg_procheck_05.pro
end
""")

command("coor @gb3_xray.pdb")

#command("delete select ((resid 73:76) or (resid 68 and name he2)) end")
#command("delete select (resid 68 and name he2) end")

#
# create Simulation with ensembleSize ensemble members
#
esim = EnsembleSimulation("ensemble",ensembleSize)




trace.suspend()

def patternDot(p1,p2):
    ret = 0.
    for key in p1.keys():
        ret += sign( dot(p1[key], p2[key]) )
        pass
    ret /= len(p1)
    return ret

def crossDot(p1,p2):
    ret = 0.
    for key in p1.keys():
        ret += dot(p1[key], p2[key])
        pass
    ret /= len(p1)
    return ret

def sign(x):
    if x<0.: return -1
    else: return 1.


#
# main structure loop
#

print "\nPerforming analysis\n"

def structLoopAction(loopInfo):
    global filename, esim, aveFittingAngle
    file = loopInfo.makeFilename(filename)
    PDBTool(file).read()

    #esim.barrier()

    # pattern calculation
    global vectors
    for bondAtoms in bondVectors:
        vector = {}
        for resid in range(1,selectTools.maxResid()+1):
            bondVecs=[]
            for index in range( esim.size() ):
                uVec = 0
                try:
                    memberSim = esim.members(index)
                    aAtom = AtomSel("resid %d and name %s" %
                                    (resid,bondAtoms[0]),
                                    memberSim)[0]
                    bAtom = AtomSel("bondedto id %d and name %s" %
                                    (aAtom.index()+1,bondAtoms[1]),
                                    memberSim)[0]
                    uVec = unitVec(bAtom.pos()-aAtom.pos())
                except IndexError:
                    pass
                bondVecs.append( uVec  )
                pass
            # ???
            #if norm(bondVecs[0])>0.1 and norm(bondVecs[1])>0.1 and \
            #   norm(cross(bondVecs[0],bondVecs[1]))>1e-3:
            if uVec: vector[resid] = bondVecs
            #    #print "small cross:", resid, bondVecs[0],bondVecs[1]
            #    pass
            pass
        vectors[bondAtoms].append( vector )
        pass
    return


vectors = {}
for bondAtoms in bondVectors:
    vectors[bondAtoms] = []
    pass


StructureLoop(numStructures=totStructs,
              structLoopAction=structLoopAction).run()

if esim.member().memberIndex(): sys.exit(0)

numResids = selectTools.maxResid()

resids = [i+1 for i in range(numResids)]

for bondAtoms in bondVectors:
    probBin={}
    countBin={}
    for k in compResids:
        probBin[k] = {}
        countBin[k] = {}
        for l in resids:
            probBin[k][l] = 0.
            countBin[k][l] = 0
            pass
        pass

    sys.stdout.write("%s-%s progress: " % bondAtoms)
    for k in compResids:
        sys.stdout.write("%d " % k)
        sys.stdout.flush()
        
        for i in range( totStructs ):
            for j in range(i+1, totStructs ):
                index0=0
                index1=1
                try:
                    vector_ik = vectors[bondAtoms][i][k]
                    vector_jk = vectors[bondAtoms][j][k]
                    if (dot(vector_ik[0],vector_jk[0]) < 
                        dot(vector_ik[0],vector_jk[1]) ):
                        index0=1
                        index1=0
                        pass
                    for l in resids:
                        countBin[k][l] += 1
                        try:
                            vector_il = vectors[bondAtoms][i][l]
                            vector_jl = vectors[bondAtoms][j][l]
                            if (dot(vector_il[0],vector_jl[index0]) >
                                dot(vector_il[0],vector_jl[index1]) ):
                                probBin[k][l] += 1
                                pass
                            if (dot(vector_il[0],vector_jl[index0]) ==
                                dot(vector_il[0],vector_jl[index1]) ):
                                #print "bad data point: ", i, j, k, l
                                pass
                            pass
                        except KeyError:
                            countBin[k][l] -= 1
                            pass
                        pass
                    pass
                except KeyError:
                    pass
                pass
            pass
        pass
    print

    print "\nResults for %s-%s\n\n" % bondAtoms
    line= "resid "
    for k in compResids:
        line += "%4d   " % k
        pass
    print line

    for l in resids:
        line = "%5d " % l
        for k in compResids:
            if countBin[k][l]:
                line +=  "%6.2f " % (2*probBin[k][l]/countBin[k][l]-1)
            else:
                line +=  "%6.2f " % 0.
                pass
            pass
        print line
        pass
    pass
