#generates calculated dipolars with noise from an ensemble of N=2
totStructs = 100          # number of structures to calculate
ensembleSize=2           # number of ensemble members
seed=6
outPDB_template = "SCRIPT_%d_STRUCTURE_MEMBER.sa" % ensembleSize

sim = xplor.simulation
command = xplor.command


#
# load up needed packages
#

from atomAction import randomizeVelocities, translateFit, PrintPos
from rdcPotTools import create_RDCPot, scale_toNH
import rdcPotTools
from varTensorTools import create_VarTensor, addAxisAtoms, calcTensor
from varTensorTools import configIVM, configIVM_fixDa, configIVM_fixRh
from varTensorTools import configIVM_varyDa, configIVM_varyRh
from atomSel import AtomSel
from ensembleSimulation import EnsembleSimulation
from xplorPot import XplorPot
from jCoupPot import JCoupPot
from noePot import NOEPot
from avePot import AvePot
from pdbTool import PDBTool
from shapePot import ShapePot
from math import sqrt, acos, pi
from vec3 import *
from simulationTools import *
from ncsPot import NCSPot
import simulation
import trace
import sys
import ivm
import selectTools
import protocol
import random
write = sys.stdout.write

simWorld.setRandomSeed(seed)
sys.stderr = sys.stdout #stderr is redirected to stdout



#----------------------------------------------------------------------
# read in the PSF file and initial structure

command("structure @gb3.psf end")


command("""
param
  @parallhdg_procheck_05.pro  !FIX: should this be saved to TOPPAR??
end
""")

command("coor @gb3_refined_IV.pdb")



#command("delete select ((resid 73:76) or (resid 68 and name he2)) end")
#command("delete select (resid 68 and name he2) end")

#
# create Simulation with ensembleSize ensemble members
#
esim = EnsembleSimulation("ensemble",ensembleSize)

PDBTool( "tor_cross_all_two_2_0_%d.sa" % esim.member().memberIndex() ).read()


#!----------------------------------------------------------------------
#! set the weights for the experimental eergy terms
    
k_noe  = 30.0   #   ! noes
noeexp = 2.0
asym  = 0.1    #   ! slope of NOE potential
k_cdi  = 10.0   #   ! torsion angles
k_rama = 0.002  #    !rama
kimdb = 0.001


protocol.initCollapse(sel="resid 1:56",
                      Rtarget=10.6)







#
# now initialize dipolar coupling potential terms
#

trace.suspend()

def create_and_setup_rdc(name,file):
    axis = addAxisAtoms()
    print "axis:", axis
    write("creating rdc[%8s]..." %name)
    oTensor=create_VarTensor(name,axis=axis)
    rdc = create_RDCPot(name,oTensor=oTensor,file=file)
    calcTensor(oTensor)
    #if esim.member().memberIndex()==0:
    #    AtomSel("resname ANI and name X",esim.members(0))[0].setPos(3,2,1)
    #    pass
    #AtomSel("resname ANI and name PA1",esim).apply(PrintPos())
    print " Da = %6.2f   Rh = %6.3f" % (oTensor.Da(), oTensor.Rh())
    oTensor.setEnsembleDa(1)
    oTensor.setEnsembleRh(1)
    # Da(0): want potential parameters to be *exactly* the same
    # for all simulation members
    global esim
    esim.sync()
    oTensor.setSpreadDa(1e-5*abs(oTensor.Da(0))) 
    oTensor.setSpreadRh(1e-5)
    oTensor.setScaleDa(1e5)
    oTensor.setScaleRh(1e5)
    return rdc

def create_dependent_rdc(name,file,type,rdc_nh):
    """create an rdc pot term for a non-NH expt. carried out in the
    same medium as the given nh expt.
    """
    write("creating rdc[%8s]..." %name)
    oTensor = rdc_nh.oTensor
    rdc = create_RDCPot(name,file,oTensor=oTensor)
    scale_toNH(rdc,type)
    print " Da = %6.2f   Rh = %6.3f" % (oTensor.Da(), oTensor.Rh())
    rdc.setAveType("sum")
    oTensor.setEnsembleDa(1)
    oTensor.setEnsembleRh(1)
    oTensor.setSpreadDa(1e-5*abs(rdc_nh.oTensor.Da(0)))
    oTensor.setSpreadRh(1e-5)
    oTensor.setScaleDa(1e5)
    oTensor.setScaleRh(1e5)
    return rdc
    

#
# HN-N rdc terms
#
rdcs = {}
rdc_scale = {}
#
# rdc terms are scaled relative to rdc_scaleRef: the scale factor
# is the square of the ratio of Das
#
rdc_scaleRef="nh_peg" 
for (name,file,scale) in (("nh_peg" ,"peg_nh.tbl"    ,15.0),
                          ("nh_bic" ,"bicelle_nh.tbl",15.0),
                          ("nh_ngel","ngel_nh.tbl"   ,15.0),
                          ("nh_pgel","pgel_nh.tbl"   ,15.0),
                          ("nh_pf1" ,"pf1_nh.tbl"    ,15.0)):
    rdcs[name] = create_and_setup_rdc(name,file)
    scale *= ( rdcs[rdc_scaleRef].oTensor.Da(0) /
               rdcs[name].oTensor.Da(0) )**2
    rdcs[name].setScale(scale)
    rdc_scale[name] = scale
    pass

    
for (name,nh_name,type,file,scale) in \
    (("caco_bic" ,"nh_bic" ,"CACO","bicelle_caco.tbl",100.0),
     ("caco_ngel","nh_ngel","CACO","ngel_caco.tbl"   ,100.0),         
     ("caco_pgel","nh_pgel","CACO","pgel_caco.tbl"   ,100.0),
     ("caco_pf1" ,"nh_pf1" ,"CACO","pf1_caco.tbl"    ,100.0),
     ("caco_peg" ,"nh_peg" ,"CACO","peg_caco.tbl"    ,100.0),
     ("ch_bic"   ,"nh_bic" ,"CAHA","bicelle_ch.tbl"  ,3.0),
     ("ch_ngel"  ,"nh_ngel","CAHA","ngel_ch.tbl"     ,3.0),
     ("ch_pgel"  ,"nh_pgel","CAHA","pgel_ch.tbl"     ,3.0),
     ("ch_pf1"   ,"nh_pf1" ,"CAHA","pf1_ch.tbl"      ,3.0),
     ("ch_peg"   ,"nh_peg" ,"CAHA","peg_ch.tbl"      ,3.0),
     ("nco_bic"  ,"nh_bic" ,"NCO" ,"bicelle_nco.tbl" ,100.0),
     ("nco_ngel" ,"nh_ngel","NCO" ,"ngel_nco.tbl"    ,100.0),
     ("nco_pgel" ,"nh_pgel","NCO" ,"pgel_nco.tbl"    ,100.0),
     ("nco_pf1"  ,"nh_pf1" ,"NCO" ,"pf1_nco.tbl"     ,100.0),
     ("nco_peg"  ,"nh_peg" ,"NCO" ,"peg_nco.tbl"     ,100.0)    ):
    rdcs[name] = create_dependent_rdc(name,file,type,rdcs[nh_name])
    scale *= ( rdcs[rdc_scaleRef].oTensor.Da(0) /
               rdcs[name].oTensor.Da(0) )**2
    rdcs[name].setScale(scale)
    rdc_scale[name] = scale
    pass



refineRDC = PotList("refineRDC")
crossRDC  = PotList("crossRDC")
media = ("bic", "ngel", "pgel", "pf1", "peg")
for expt in ["nh", "caco", "nco"]:
    for medium in media:
        refineRDC.add( rdcs[expt + '_' + medium] )
        refineRDC.add( rdcs[expt + '_' + medium].oTensor )
    pass
for expt in ["ch"]:
    for medium in media: crossRDC.add( rdcs[expt + '_' + medium] )
    pass

noiseSize=2.0
exptNoise = {}
exptNoise["nh"]   = 0.26
exptNoise["caco"] = 0.1
exptNoise["ch"]   = 0.5
exptNoise["nco"]  = 0.1
random.seed(seed)
for rdc in list(refineRDC)+list(crossRDC):
    exptType = rdc.instanceName().split("_")[0]
    for restraint in rdc.restraints():
        noise = random.gauss(0,noiseSize) * exptNoise[exptType]
        obs = restraint.obs()
        orig = restraint.calcd()
        restraint.setObs( orig + noise )
        print rdc.instanceName(), restraint.obs(), orig, obs
        pass
    open('n2_'+rdc.instanceName()+'.tbl','w').write(rdcPotTools.makeTable(rdc))
    pass

sys.exit()

