#
# this script calculates the properly normalized equal time correlation
# function
#


totStructs = 100          # number of structures to calculate
ensembleSize=2           # number of ensemble members
                         # the next line should refer to fitted structures
                         # produced by analyze_mean.py
filename = "tor_cross_all_two_%d_STRUCTURE_MEMBER.sa" % ensembleSize
seed=3
compResids=[ 1,2]


sim = xplor.simulation
command = xplor.command


#
# load up needed packages
#

from atomAction import randomizeVelocities, translateFit
from rdcPotTools import *
from atomSel import AtomSel
from ensembleSimulation import EnsembleSimulation
import ensembleSimulation
from math import sqrt, acos, pi
from vec3 import *
from simulationTools import *
import simulation
import trace
import sys
import selectTools
from pdbTool import PDBTool
from dihedral import Dihedral


simWorld.setRandomSeed(seed)
sys.stderr = sys.stdout #stderr is redirected to stdout



#----------------------------------------------------------------------
# read in the PSF file and initial structure

xplor.command("structure @gb3.psf end")
xplor.command("coor @gb3_xray.pdb")

#
# create Simulation with ensembleSize ensemble members
#
esim = EnsembleSimulation("ensemble",ensembleSize)




trace.suspend()


#
# main structure loop
#

print "\nPerforming analysis\n"

def structLoopAction(loopInfo):
    global filename, esim, aveFittingAngle
    file = loopInfo.makeFilename(filename)
    PDBTool(file).read()


    for index in range(esim.size()):
        for resid in phiDihedrals.keys():
            try:
                phi = phiDihedrals[resid][index].value()
                phiVals[resid][loopInfo.count][index] = phi
            except IndexError:
                pass
            pass
        for resid in psiDihedrals.keys():
            try:
                psi = psiDihedrals[resid][index].value()
                psiVals[resid][loopInfo.count][index] = psi
            except IndexError:
                pass
            pass
        pass
    return


phiVals = {}
psiVals = {}
phiDihedrals = {}
psiDihedrals = {}

resids = [i+1 for i in range(selectTools.maxResid("not resname ANI"))]

for resid in resids:
    phiVals[resid] = []
    psiVals[resid] = []
    for cnt in range(totStructs):
        phiVals[resid].append([0]*esim.size())
        psiVals[resid].append([0]*esim.size())
        pass
    phiDihedrals[resid] = []
    psiDihedrals[resid] = []

                

    for cnt in range(esim.size()):
        sim = esim.members(cnt)
        try:
            phi = Dihedral(AtomSel("resid %d and name C" % (resid-1),sim),
                           AtomSel("resid %d and name N" % resid    ,sim),
                           AtomSel("resid %d and name CA"% resid   ,sim),
                           AtomSel("resid %d and name C" % resid    ,sim))
            phiDihedrals[resid].append(phi)
        except IndexError:
            pass

        try:
            psi = Dihedral(AtomSel("resid %d and name N" % resid ,sim),
                           AtomSel("resid %d and name CA"% resid,sim),
                           AtomSel("resid %d and name C" % resid ,sim),
                           AtomSel("resid %d and name N" % (resid+1) ,sim))
                
            psiDihedrals[resid].append(psi)
        except IndexError:
            pass
        pass
    pass



ang1Vals = phiVals
ang2Vals = phiVals

StructureLoop(numStructures=totStructs,
              structLoopAction=structLoopAction).run()

if esim.member().memberIndex(): sys.exit(0)

numResids = selectTools.maxResid()


deltaAng1={}
for resid in resids:
    deltaAng1[resid] = []
    for cnt in range(totStructs):
        deltaAng1[resid].append([0]*esim.size())
        #print resid, cnt, ang1Vals[resid][cnt]
        pass

    pass

def getBranch(theta1,theta2):
    """return the branch number n such that n*2*PI+theta1-theta2 is
    minimal"""
    return round((theta2-theta1)/360)

for resid in ang1Vals.keys():
    for structNum in range(totStructs):
        aveAng1=0
        for mem in range(esim.size()):
            ang = ang1Vals[resid][structNum][mem]
            ang += 2*180*getBranch(ang,ang1Vals[resid][structNum][0])
            ang1Vals[resid][structNum][mem] = ang
            aveAng1 += ang
            pass
        aveAng1 /= esim.size()
        for mem in range(esim.size()):
            deltaAng1[resid][structNum][mem] = ang1Vals[resid][structNum][mem] -\
                                              aveAng1
            pass
        pass
    pass

deltaAng2={}
for resid in resids:
    deltaAng2[resid] = []
    for cnt in range(totStructs):
        deltaAng2[resid].append([0]*esim.size())
        pass

    pass
for resid in ang2Vals.keys():
    for structNum in range(totStructs):
        aveAng2=0
        for mem in range(esim.size()):
            ang = ang2Vals[resid][structNum][mem]
            ang += 2*180*getBranch(ang,ang2Vals[resid][structNum][0])
            ang2Vals[resid][structNum][mem] = ang
            aveAng2 += ang
            pass
        aveAng2 /= esim.size()
        for mem in range(esim.size()):
            deltaAng2[resid][structNum][mem] = ang2Vals[resid][structNum][mem] -\
                                              aveAng2
            pass
        pass
    pass

corr = {}
for i in resids:
    corr[i] = {}
    deltaAng1_2 = {}
    deltaAng2_2 = {}
    pass


# specialized for two-membered ensembles
for k in ang1Vals.keys():
    deltaAng1_2[k] = 0
    for i in range(totStructs):
        deltaAng1_2[k] += deltaAng1[k][i][0]**2
        pass
    pass
for l in ang2Vals.keys():
    deltaAng2_2[l] = 0
    for i in range(totStructs):
        deltaAng2_2[l] += deltaAng2[l][i][0]**2
        pass
    pass

for k in ang1Vals.keys():
    for l in ang2Vals.keys():
        corr[k][l] = 0
        for i in range(totStructs):
            plusMem=0
            if deltaAng1[k][i][plusMem]<0: plusMem=1
            corr[k][l] += deltaAng1[k][i][plusMem] * \
                          deltaAng2[l][i][plusMem]
            pass
        pass
    pass

#sys.exit()
    

line= "resid "
for k in resids:
    line += "%4d   " % k
    pass
print line

for k in resids:
    line = "%5d " % k
    for l in resids:
        try:
            line +=  "%6.2f " % (corr[k][l] / sqrt( deltaAng1_2[k] *
                                                    deltaAng2_2[l] ))
        except:
            line +=  "%6.2f " % 0
            pass
        pass
    print line
    pass
