
totStructs = 100          # number of structures to calculate
ensembleSize=2          # number of ensemble members
seed=54638326
#outPDB_template = "SCRIPT_%d_STRUCTURE_MEMBER.sa" % ensembleSize
outPDB_template = "tor_cross_nh_two_%d_STRUCTURE_MEMBER.sa" % ensembleSize

sim = xplor.simulation
command = xplor.command


#
# load up needed packages
#

from atomAction import randomizeVelocities, translateFit, PrintPos
from rdcPotTools import create_RDCPot, scale_toNH
from varTensorTools import create_VarTensor, addAxisAtoms, calcTensor
from varTensorTools import configIVM, configIVM_fixDa, configIVM_fixRh
from varTensorTools import configIVM_varyDa, configIVM_varyRh
from atomSel import AtomSel
from ensembleSimulation import EnsembleSimulation
from xplorPot import XplorPot
from jCoupPot import JCoupPot
from noePot import NOEPot
from avePot import AvePot
from pdbTool import PDBTool
from shapePot import ShapePot
from math import sqrt, acos, pi
from vec3 import *
from simulationTools import *
from ncsPot import NCSPot
import simulation
import trace
import sys
import ivm
import selectTools
import protocol
write = sys.stdout.write

simWorld.setRandomSeed(seed)
sys.stderr = sys.stdout #stderr is redirected to stdout



#----------------------------------------------------------------------
# read in the PSF file and initial structure

command("structure @gb3.psf end")


command("""
param
  @parallhdg_procheck_05.pro  !FIX: should this be saved to TOPPAR??
end
""")

command("coor @gb3_refined_IV.pdb")

#command("delete select ((resid 73:76) or (resid 68 and name he2)) end")
#command("delete select (resid 68 and name he2) end")

#
# create Simulation with ensembleSize ensemble members
#
esim = EnsembleSimulation("ensemble",ensembleSize)


#!----------------------------------------------------------------------
#! set the weights for the experimental eergy terms
    
k_noe  = 30.0   #   ! noes
noeexp = 2.0
asym  = 0.1    #   ! slope of NOE potential
k_cdi  = 10.0   #   ! torsion angles
k_rama = 0.002  #    !rama
kimdb = 0.001


protocol.initCollapse(sel="resid 1:56",
                      Rtarget=10.6)







#
# now initialize dipolar coupling potential terms
#

trace.suspend()

def create_and_setup_rdc(name,file):
    axis = addAxisAtoms()
    print "axis:", axis
    write("creating rdc[%8s]..." %name)
    oTensor=create_VarTensor(name,axis=axis)
    rdc = create_RDCPot(name,oTensor=oTensor,file=file)
    calcTensor(oTensor)
    #if esim.member().memberIndex()==0:
    #    AtomSel("resname ANI and name X",esim.members(0))[0].setPos(3,2,1)
    #    pass
    #AtomSel("resname ANI and name PA1",esim).apply(PrintPos())
    print " Da = %6.2f   Rh = %6.3f" % (oTensor.Da(), oTensor.Rh())
    oTensor.setEnsembleDa(1)
    oTensor.setEnsembleRh(1)
    # Da(0): want potential parameters to be *exactly* the same
    # for all simulation members
    global esim
    esim.sync()
    oTensor.setSpreadDa(1e-5*abs(oTensor.Da(0))) 
    oTensor.setSpreadRh(1e-5)
    oTensor.setScaleDa(1e5)
    oTensor.setScaleRh(1e5)
    return rdc

def create_dependent_rdc(name,file,type,rdc_nh):
    """create an rdc pot term for a non-NH expt. carried out in the
    same medium as the given nh expt.
    """
    write("creating rdc[%8s]..." %name)
    oTensor = rdc_nh.oTensor
    rdc = create_RDCPot(name,file,oTensor=oTensor)
    scale_toNH(rdc,type)
    print " Da = %6.2f   Rh = %6.3f" % (oTensor.Da(), oTensor.Rh())
    rdc.setAveType("sum")
    oTensor.setEnsembleDa(1)
    oTensor.setEnsembleRh(1)
    oTensor.setSpreadDa(1e-5*abs(rdc_nh.oTensor.Da(0)))
    oTensor.setSpreadRh(1e-5)
    oTensor.setScaleDa(1e5)
    oTensor.setScaleRh(1e5)
    return rdc
    

#
# HN-N rdc terms
#
rdcs = {}
rdc_scale = {}
#
# rdc terms are scaled relative to rdc_scaleRef: the scale factor
# is the square of the ratio of Das
#
rdc_scaleRef="nh_peg" 
for (name,file,scale) in (("nh_peg" ,"peg_nh.tbl"    ,15.0),
                          ("nh_bic" ,"bicelle_nh.tbl",15.0),
                          ("nh_ngel","ngel_nh.tbl"   ,15.0),
                          ("nh_pgel","pgel_nh.tbl"   ,15.0),
                          ("nh_pf1" ,"pf1_nh.tbl"    ,15.0)):
    rdcs[name] = create_and_setup_rdc(name,file)
    scale *= ( rdcs[rdc_scaleRef].oTensor.Da(0) /
               rdcs[name].oTensor.Da(0) )**2
    rdcs[name].setScale(scale)
    rdc_scale[name] = scale
    pass

    
for (name,nh_name,type,file,scale) in \
    (("caco_bic" ,"nh_bic" ,"CACO","bicelle_caco.tbl",100.0),
     ("caco_ngel","nh_ngel","CACO","ngel_caco.tbl"   ,100.0),         
     ("caco_pgel","nh_pgel","CACO","pgel_caco.tbl"   ,100.0),
     ("caco_pf1" ,"nh_pf1" ,"CACO","pf1_caco.tbl"    ,100.0),
     ("caco_peg" ,"nh_peg" ,"CACO","peg_caco.tbl"    ,100.0),
     ("ch_bic"   ,"nh_bic" ,"CAHA","bicelle_ch.tbl"  ,3.0),
     ("ch_ngel"  ,"nh_ngel","CAHA","ngel_ch.tbl"     ,3.0),
     ("ch_pgel"  ,"nh_pgel","CAHA","pgel_ch.tbl"     ,3.0),
     ("ch_pf1"   ,"nh_pf1" ,"CAHA","pf1_ch.tbl"      ,3.0),
     ("ch_peg"   ,"nh_peg" ,"CAHA","peg_ch.tbl"      ,3.0),
     ("nco_bic"  ,"nh_bic" ,"NCO" ,"bicelle_nco.tbl" ,100.0),
     ("nco_ngel" ,"nh_ngel","NCO" ,"ngel_nco.tbl"    ,100.0),
     ("nco_pgel" ,"nh_pgel","NCO" ,"pgel_nco.tbl"    ,100.0),
     ("nco_pf1"  ,"nh_pf1" ,"NCO" ,"pf1_nco.tbl"     ,100.0),
     ("nco_peg"  ,"nh_peg" ,"NCO" ,"peg_nco.tbl"     ,100.0)    ):
    rdcs[name] = create_dependent_rdc(name,file,type,rdcs[nh_name])
    scale *= ( rdcs[rdc_scaleRef].oTensor.Da(0) /
               rdcs[name].oTensor.Da(0) )**2
    rdcs[name].setScale(scale)
    rdc_scale[name] = scale
    pass



refineRDC = PotList("refineRDC")
crossRDC  = PotList("crossRDC")
media = ("bic", "ngel", "pgel", "pf1", "peg")
for expt in ["ch", "nco", "caco"]:
    for medium in media:
        refineRDC.add( rdcs[expt + '_' + medium] )
        refineRDC.add( rdcs[expt + '_' + medium].oTensor )
    pass
for expt in ["nh"]:
    for medium in media: crossRDC.add( rdcs[expt + '_' + medium] )
    pass


command("""
hbda
  nres 800
  class back
  @hbda.tbl
  force 500.0
end
""")

command("""
noe
   reset
   nres = 10000
   class all
   @hbond.tbl
end
! set echo on message on end
noe
  ceiling 1000
  averaging  all sum
  potential  all square   !soft
  scale      all %f
  sqconstant all 1.0
  sqexponent all 2
!  soexponent all 1
!  rswitch    all 1.0
!  sqoffset   all 0.0
!  asymptote  all 2.0
end

set message off echo off end
end""" % k_noe)

command("print threshold=0.5 noe")

protocol.initDihedrals(scale=k_cdi,
                       filenames="dihed_g_all.tbl",
                       useDefaults=0)

command("print threshold=0.0 cdih")

Jhnha = JCoupPot('hnha',open('jna_coup.tbl').read())

potList = PotList()

enoe = NOEPot('enoe')
enoe.addRestraints( open('hbond.tbl').read() )

enoe.setScale( k_noe )
enoe.setAveExp( noeexp )
enoe.setDOffset(0.)
enoe.setHardExp(2 )
enoe.setThreshold(0.1)
enoe.setPotType( "hard" )
enoe.setAveType( "sum" )

potList.add( enoe )




# find geometric center of protein
centerSel = AtomSel("not resname ANI") # selection used to find center
centerPos = Vec3(0,0,0)
for atom in centerSel: centerPos += atom.pos()
centerPos /= len( centerSel )

print "center: ", centerPos

# exterior atoms defining protein shape
shapeSel = AtomSel("(not resname ANI) and not (point (%f, %f, %f) cut 5.)" %
                   centerPos.tuple())

trace.resume()
shape = ShapePot("shape",shapeSel)
print "shape selection includes %d atoms" % len( shape.atomSel() )
shape.setSizeScale( 1 )
shape.setOrientScale( 0 )
shape.setSizePotType("square") #allow small size error
shape.setSizeTol(2)
shape.setTargetType("average")

# merged two terms
#potList.add( shape )

#orient = ShapePot("orient",shape.atomSel())
#orient.setSizeScale( 0 )
orient = shape
orient.setOrientScale( 1000 )
orient.setOrientPotType("square") #allow 1 degree orientation error
orient.setOrientTol(0.5)
orient.setTargetType("average")

potList.add( orient )


#ncs term to keep members of ensemble in similar orientations
ncs = NCSPot("ncs",AtomSel("""name CA"""))

ncs.setScale( 100.0 )
ncs.setPotType( "square" )
ncs.setTol( 0.3 )
potList.add( ncs )


def setConstraints(k_ang,k_imp):
    """scale potential terms and turn off terms for rdc atoms
       NOTE: constraints command can't be split up"""
    constraintCmd = """
    constraints
    interaction (not (resname ANI)) (not (resname ANI))
    weights * 1 angles %f improper %f end
    """ % (k_ang, k_imp)
    constraintCmd += "end\n"

    print constraintCmd
    command( constraintCmd )
    return

protocol.initNBond()
protocol.initRamaDatabase()

#vdw weight
rcon  = 0.003
command("parameters nbonds atom rcon=%f end end" % rcon) 


mini = ivm.IVM(esim)

potList.add( refineRDC )
#potList.add( crossRDC )

trace.suspend()
for rdc in rdcs.values():
    configIVM(rdc.oTensor,mini)
    configIVM_fixDa(rdc.oTensor,mini)
    configIVM_fixRh(rdc.oTensor,mini)
    pass
trace.resume()

protocol.initMinimize(mini,potList)
mini.fix( AtomSel("not resname ANI") )
mini.autoTorsion()
#mini.setVerbose(mini.printLoopInfo | mini.printLoopDebug | mini.printNodeDef)

mini.run()

#
# ensemble average over the following XPLOR energy terms
#
for term in ["BOND", "ANGL", "IMPR", "VDW", "RAMA",
             "CDIH", "COLL", "HBDA", "NOE"]:
    potList.add( AvePot(XplorPot,term) )
    pass

#set up dynamics manipulators

dyn = ivm.IVM(esim) #manipulator for T-A dynamics
dynx = ivm.IVM(esim) #manipulator for Cartesian dynamics

trace.suspend()
for manip in (dyn,dynx):

    manip.setPotList( potList )

    for key in filter(lambda x: x.startswith("nh_"),
                      rdcs.keys()                  ):
        rdc = rdcs[key]
        configIVM(rdc.oTensor,manip)
        configIVM_varyDa(rdc.oTensor,manip)
        configIVM_varyRh(rdc.oTensor,manip)
        pass

    selectTools.IVM_breakProlines(manip)
trace.resume()

selectTools.IVM_groupRigidSidechain(dyn)
dyn.autoTorsion()

dynx.breakAllBondsIn( AtomSel("""not resname ANI"""))
dynx.setBaseAtoms( AtomSel("""not resname ANI"""))


#set atom masses
trace.suspend()
for atom in AtomSel("not (resname ANI)"): atom.setMass(30.)
for atom in AtomSel("resname ANI"): atom.setMass(100.)
for atom in AtomSel("all"): atom.setFric(10.)
trace.resume()

# these are starting coordinates for all structures
initCoords=sim.atomPosArr()


#
# definition of cooling loop and associated parameters
#


def coolAndMinimize():


    command("parameters nbonds atom rcon =1.0 end end") #vdw weight

    #
    # parameters changed during cooling loop
    #
    global radius, k_ang, k_imp, k_vdw, k_sani
    radius = MultRamp(0.81,0.8)
    k_vdw  = MultRamp(0.1,4.0)
    k_ang  = MultRamp(0.4,1.0)
    k_imp  = MultRamp(0.1,1.0)
    k_noe  = MultRamp(2.0,30.0,
                        "enoe.setScale( VALUE );" + 
                        "command('noe scale all VALUE end')"
                      )
    noe_exp= MultRamp(2.0,6.0, "enoe.setAveExp( VALUE )"
                      )
    k_cdi  = MultRamp(1.0,200.0,
                        "command('restraints dihed scale VALUE end')")
    k_rama = MultRamp(0.002,1.0,
                        "command('rama scale VALUE end')")
    k_imdb = MultRamp(0.001,2000.0)
    k_sani = MultRamp(0.01,1.0)

    #
    # extra commands to run during each iteration of the cooling loop
    #
    def extraCoolingCmds(coolLoopInfo):
        #
        # scale potential terms and turn off terms for rdc atoms
        #
        global radius, k_ang, k_imp, k_vdw, k_sani
        for key in rdcs.keys():
            rdcs[key].setScale( rdc_scale[key] * k_sani.value() )
            pass


        setConstraints(k_ang.value(),k_imp.value())

        command("parameter nbonds rcon=%f repel=%f end end" %
                (k_vdw.value(),radius.value()) )
        return

    #
    # cool performs MD simulated annealing
    #
    init_t  = 400.01
    randomizeVelocities(init_t)
    #print dyn.info()
    cool = AnnealIVM(initTemp     = init_t,
                     finalTemp    = 300.0,
                     tempStep     = 50.0,
                     ivm          = dyn,
                     extraCommands= extraCoolingCmds,
                     rampedParams = [radius, k_vdw,  k_ang,  k_imp,  k_noe,
                                     noe_exp, k_cdi, k_rama, k_imdb, k_sani])


    protocol.initDynamics(dyn,init_t,potList)

    #steps and endtime for dynamics
    cool_steps = 100 #total number of dynamics steps during cooling
    nstep = int(cool_steps/(cool.numSteps+1) )
    endtime = nstep*0.002

    dyn.setFinalTime(endtime)

    cool.run()

    protocol.initMinimize(dyn)
    dyn.setNumSteps(500)
    dyn.setMaxCalls(20000)
    dyn.setPrintInterval(10)
    #simWorld.setLogLevel( "debug" )
    #dyn.setVerbose( 0xffff )
    dyn.run()

    #
    #minimization in cartesian space
    #
    protocol.initMinimize(dynx,potList)
    dynx.run()

    return


def performAnalysis(structLoopInfo):
    #
    # analysis phase:
    # -dipolar coupling terms are ensemble quantities.
    # -other potential terms are evaluated separately for each
    #  structure in the ensemble.
    #
    
    # there had been code here to fit other tensor atoms (not used in
    # refinement) to the determined structure.
    # This should now be accomplished using calcTensor()

    ##########################################################3
    # is any term missing from potList at this point?
    global potList
    ener = potList.calcEnergy().energy
    print "structure: %3d  total energy: %f" % (structLoopInfo.count ,ener)

    #translate ensemble members to minimize backbone rmsd
    esim.setAtomPosArr( translateFit(esim.members(0).atomPosArr(),
                                     AtomSel("name C or name N or name CA")) )

    
    memberIndex = esim.member().memberIndex()

    print ncs.info()
    print ncs.showPositions()


    print shape.info()
    print shape.showVectors()
    print shape.showValues()
    trace.suspend()
    print "eigenvalues:"
    for index  in range(esim.size()):
        print "\t%7.2f %7.2f %7.2f" % (shape.getContrib(index,0).value,
                                       shape.getContrib(index,1).value,
                                       shape.getContrib(index,2).value)
        pass

    shape_angle = shape.rotation(memberIndex)
    for index  in range(esim.size()):
        print "shape: rotation from target tensor (%d): %f"% \
              (index,shape.rotation(index))
        pass
    trace.resume()
    

    #Enoe = 0
    #Enoe = noe.calcEnergy().energy
    #print Enoe
    enoe.setThreshold(0.5)
    print enoe.showViolations()
    erms_noe = enoe.rms()
    edev_noe = enoe.deviation()
    eviol_noe = enoe.violations()
    print enoe.info()

    #j-coupling terms
    trace.suspend()
    for pot in [Jhnha, ]:
        pot.setThreshold(0.1)
        
        print pot.showViolations()
        print pot.info()
    trace.resume()

    
    #global outPDB_template
    pdbFile = PDBTool( structLoopInfo.makeFilename( outPDB_template ) )
        

    #coupClasses = ("hnha", "hncb", "hnco", "coha", "cocb", "coco")
    #rms_coup={}
    #for coupClass in coupClasses:
    #    rms_coup[coupClass] = float(command("""couplings print
    #                                        threshold=0.0 class %s end""" %
    #                                        coupClass, "result")[0])
    #    pass


    remarks = analyze(potList,crossRDC)


    remarks+= "angle_diff: %f\n" % shape_angle
    remarks+= """
    =============================================================== 
    ensemble noe
    """
    remarks+= "rms deviation viol\n"
    remarks+= "NOE ensemble: %f  %f %d\n" % \
              (erms_noe, edev_noe, eviol_noe)
    remarks+= """
    ===============================================================
    jcoup ensemble
    """
    line1= "J_individual"
    line2= "J_rmsd_ensemble:"
    line3= "J_dev_ensemble:"
    for pot in [Jhnha,]:
        line1 += " %s" % pot.instanceName()
        line2 += " %f" % pot.rms()
        line3 += " %f" % pot.deviation()
        pass

    remarks += line1 + '\n' + line2 + '\n' + line3 + '\n'



    for line in remarks.splitlines(): pdbFile.addRemark( line )

    pdbFile.write()
    return


#
# main structure loop
#

def structLoopAction(loopInfo):
    numReps = 16
    k_shape = MultRamp(1.,10.,
                       "orient.setOrientScale( VALUE )")
    k_shape.init( numReps )
    for repetition in range( numReps ):
        k_shape.update()
        coolAndMinimize()
        pass
    performAnalysis(loopInfo)



StructureLoop(numStructures=totStructs,
              structLoopAction=structLoopAction).run()
    

